pub fn cbrt<T: Roots>(x: T) -> TExpand description
Returns the truncated principal cube root of an integer – see Roots::cbrt.
main (development) branch of crypto-glue.pub fn cbrt<T: Roots>(x: T) -> TReturns the truncated principal cube root of an integer – see Roots::cbrt.