pub fn sqrt<T: Roots>(x: T) -> TExpand description
Returns the truncated principal square root of an integer – see Roots::sqrt.
main (development) branch of crypto-glue.pub fn sqrt<T: Roots>(x: T) -> TReturns the truncated principal square root of an integer – see Roots::sqrt.